@@ -1,4 +1,4 @@
-from gmat.uvlmm.uvlmm_varcom import wemai_multi_gmat
+from gmat.uvlmm.uvlmm_varcom import wemai_multi_gmat, _wemai_multi_gmat
 from gmat.uvlmm.uvlmm_varcom_eigen import *
 from gmat.uvlmm.uvlmm_gwas import *
 from gmat.uvlmm.design_matrix import design_matrix_wemai_multi_gmat
